@@ -1,16 +1,16 @@
 package Sort::Sub::naturally;
 
-our $DATE = '2016-12-18'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2018-01-15'; # DATE
+our $VERSION = '0.110'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
 sub gen_sorter {
-    my ($is_reverse, $is_ci) = @_;
+    require Sort::Naturally;
 
-    my $re = qr/([+-]?\d+|\D+)/;
+    my ($is_reverse, $is_ci) = @_;
 
     sub {
         no strict 'refs';
@@ -19,25 +19,11 @@ sub gen_sorter {
         my $a = @_ ? $_[0] : ${"$caller\::a"};
         my $b = @_ ? $_[1] : ${"$caller\::b"};
 
-        my @a_parts = +($is_ci ? lc($a) : $a) =~ /$re/g;
-        my @b_parts = +($is_ci ? lc($b) : $b) =~ /$re/g;
-
-        #use DD; dd \@a_parts;
-
-        my $i = 0;
-        my $cmp = 0;
-        for (@a_parts) {
-            last if $i >= @b_parts;
-            #say "D:$a_parts[$i] <=> $b_parts[$i]";
-            if ($a_parts[$i] =~ /\D/ || $b_parts[$i] =~ /\D/) {
-                $cmp = $a_parts[$i] cmp $b_parts[$i];
-            } else {
-                $cmp = $a_parts[$i] <=> $b_parts[$i];
-            }
-            last if $cmp;
-            $i++;
+        if ($is_reverse) {
+            Sort::Naturally::ncmp($b, $a);
+        } else {
+            Sort::Naturally::ncmp($a, $b);
         }
-        $is_reverse ? -1*$cmp : $cmp;
     };
 }
 
@@ -56,7 +42,7 @@ Sort::Sub::naturally - Sort naturally
 
 =head1 VERSION
 
-This document describes version 0.10 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-12-18.
+This document describes version 0.110 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2018-01-15.
 
 =for Pod::Coverage ^(gen_sorter)$
 
@@ -90,6 +76,11 @@ Use in shell/CLI with L<sortsub> (from L<App::sortsub>):
 
 This module can generate sort subroutine. It is meant to be used via L<Sort::Sub>, although you can also use it directly via C<gen_sorter()>.
 
+=head1 NOTES
+
+Uses L<Sort::Naturally>'s C<ncmp> as the backend. Always sorts
+case-insensitively.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
@@ -118,7 +109,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
